==========
defi-tools
==========


.. image:: https://img.shields.io/pypi/v/defi_tools.svg
        :target: https://pypi.python.org/pypi/defi_tools

.. image:: https://img.shields.io/travis/deanjdominguez/defi_tools.svg
        :target: https://travis-ci.com/deanjdominguez/defi_tools

.. image:: https://readthedocs.org/projects/defi-tools/badge/?version=latest
        :target: https://defi-tools.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python Boilerplate contains all the boilerplate you need to create a Python package.


* Free software: MIT license
* Documentation: https://defi-tools.readthedocs.io.


Features
--------

* TODO

```mermaid
classDiagram
class Square~Shape~{
    int id
    List~int~ position
    setPoints(List~int~ points)
    getPoints() List~int~
}

Square : -List~string~ messages
Square : +setMessages(List~string~ messages)
Square : +getMessages() List~string~
```

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
